@@ -518,7 +518,7 @@ class MultiLayerNet:
         layer_info = load_data.get("LayerInfo")
         for layer_encoded in layer_info:
             layer = jsp.decode(layer_encoded)
-            print(layer_encoded)
+            # print(layer_encoded)
 
             self.add_layer(layer)
 
@@ -526,7 +526,7 @@ class MultiLayerNet:
         other_params = load_data.get("OtherParams").item()
 
         for param_name, param_value in self.params.items():
-            print(param_name)
+            # print(param_name)
 
             layer_idx = int(re.findall(r'[0-9]+', param_name)[0])
             param_kind = re.sub(r'[0-9]+', '', param_name)
@@ -547,8 +547,8 @@ class MultiLayerNet:
             if param_kind == "BN_m":
                 target_layer.running_mean = param_value
 
-                print(target_layer)
-                print(target_layer.running_mean)
+                # print(target_layer)
+                # print(target_layer.running_mean)
             elif param_kind == "BN_v":
                 target_layer.running_var = param_value
 
